extern crate chrono;
extern crate clap;
extern crate quick_xml;
// extern crate gps;

use clap::{App, Arg};

mod gps;

pub use gps::Point;
pub use gps::Track;

fn main() {
    let matches = App::new("Pothole")
        .arg(
            Arg::with_name("track")
                .long("track")
                .required(true)
                .value_name("FILE")
                .help("GPX file to process")
                .takes_value(true),
        )
        .get_matches();

    let trackfile = matches.value_of("track").unwrap_or("data/Day1-1.gpx");

    let mut trk = Track {
        ..Default::default()
    };

    trk.from_xml(trackfile.to_string());

    println!("Track name:   {:?}", trk.name);
    println!("Distance:     {:.3} km", trk.len());
    println!("Duration:     {:?} h", trk.time().num_minutes() as f32 / 60.0);
    println!("Max Speed:    {:.1} Km/h", trk.get_maxspeed());
    println!("Avg Speed:    {:.1} Km/h", trk.speed());
    
    //write bad segments
    trk.get_bad_points().to_xml();

}
