//#![windows_subsystem = "windows"]

extern crate web_view;
extern crate chrono;
extern crate clap;
extern crate quick_xml;

mod gps;

pub use gps::Point;
pub use gps::Track;
use web_view::*;

const HTML: &str = r#"
<!doctype html>
<html>
	<body>
		<button onclick="external.invoke('open')">Open</button>
		<button onclick="external.invoke('exit')">Exit</button>
		<button onclick="external.invoke('compute')">Compute</button>
	</body>
</html>
"#;

fn main() -> WVResult {
    let webview = web_view::builder()
        .title("Pothole")
        .content(Content::Html(HTML))
        .size(800, 600)
        .resizable(true)
        .debug(true)
        .user_data(())
        .invoke_handler(|webview, arg| {
            match arg {
                "open" => match webview.dialog().open_file("Please choose a file...", "")? {
                    Some(path) => {
                        webview.dialog().info("File chosen", path.to_string_lossy());
                        

                        let mut trk = Track {
                            ..Default::default()
                        };

                        trk.from_xml(&path);

                        println!("Track name:   {:?}", trk.name);
                        println!("Distance:     {:.3} km", trk.len());
                        println!("Duration:     {:?} h", trk.time().num_minutes() as f32 / 60.0);
                        println!("Max Speed:    {:.1} Km/h", trk.get_maxspeed());
                        println!("Avg Speed:    {:.1} Km/h", trk.speed());
                        
                        //write bad segments
                        trk.get_bad_points().to_xml();


                    },
                    None => {
                        webview
                        .dialog()
                        .warning("Warning", "You didn't choose a file.");
                        },
                },
                "exit" => {
                    webview.terminate();
                },
                "compute" => {

                },
                _ => unimplemented!(),
            };
            Ok(())
        })
        .build()?;

    webview.run()
}


